@@ -92,11 +92,12 @@ test.weights <- 1 / c(5, 1, 2, 4)
 test_that("Output of functions is as expected", {
   expect_equal(longitude_modulo(-361), -1)
   expect_equal(abs_vel(0.21, 0, r = 1), 0)
-  expect_equal(quantise_wsm_quality(c("A", "E", "F", "G", 5)), c(15, NA, NA, NA, NA))
+  expect_equal(as.numeric(parse_wsm_quality(c("A", "E", "F", "G", 5))), c(15, NA, NA, NA, NA))
   expect_equal(circular_median(c(15, 16)), 15.5)
   expect_equal(circular_median(c(15, 15, 16)), 15)
   expect_equal(circular_IQR(c(15, 16, 15, 15)), 1)
-  expect_equal(deviation_norm(91), 89)
+  expect_equal(deviation_norm(175, 5), 10)
+  expect_equal(deviation_norm(c(-10, 100, 170, 190, 260, 280)), c(10, 80, 10, 10, 80, 80))
   expect_equal(cartesian_to_geographical(c(10, 0, 0)), c(0, 0))
   expect_equal(geographical_to_cartesian(c(90, 0)), c(0, 0, 1))
 })
